import { z } from 'zod';
declare const messageSchema: z.ZodObject<{
    messageType: z.ZodString;
}, "strip", z.ZodTypeAny, {
    messageType: string;
}, {
    messageType: string;
}>;
export type Message = z.infer<typeof messageSchema>;
export declare function isMessage(input: unknown): input is Message;
declare const commandMessageSchema: z.ZodObject<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"command">;
    command: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    messageType: "command";
    command: string;
}, {
    messageType: "command";
    command: string;
}>;
export type CommandMessage = z.infer<typeof commandMessageSchema>;
export declare function isCommandMessage(input: unknown): input is CommandMessage;
declare const serviceConfigurationSchema: z.ZodObject<{
    serviceType: z.ZodString;
    serviceId: z.ZodString;
    remoteServiceId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    serviceType: string;
    serviceId: string;
    remoteServiceId: string;
}, {
    serviceType: string;
    serviceId: string;
    remoteServiceId: string;
}>;
export type ServiceConfiguration = z.infer<typeof serviceConfigurationSchema>;
declare const createPeerConnectionMessageSchema: z.ZodUnion<[z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"command">;
    command: z.ZodString;
}>, {
    command: z.ZodLiteral<"createPeerconnection">;
    connectionType: z.ZodString;
    connectionUrl: z.ZodString;
    services: z.ZodArray<z.ZodObject<{
        serviceType: z.ZodString;
        serviceId: z.ZodString;
        remoteServiceId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }, {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }>, "many">;
    tiebreaker: z.ZodBoolean;
}>, {
    connectionType: z.ZodLiteral<"websocket">;
    connectionOptions: z.ZodObject<{
        webSocketUrl: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        webSocketUrl: string;
    }, {
        webSocketUrl: string;
    }>;
}>, "strip", z.ZodTypeAny, {
    messageType: "command";
    command: "createPeerconnection";
    connectionType: "websocket";
    connectionUrl: string;
    services: {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }[];
    tiebreaker: boolean;
    connectionOptions: {
        webSocketUrl: string;
    };
}, {
    messageType: "command";
    command: "createPeerconnection";
    connectionType: "websocket";
    connectionUrl: string;
    services: {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }[];
    tiebreaker: boolean;
    connectionOptions: {
        webSocketUrl: string;
    };
}>, z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"command">;
    command: z.ZodString;
}>, {
    command: z.ZodLiteral<"createPeerconnection">;
    connectionType: z.ZodString;
    connectionUrl: z.ZodString;
    services: z.ZodArray<z.ZodObject<{
        serviceType: z.ZodString;
        serviceId: z.ZodString;
        remoteServiceId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }, {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }>, "many">;
    tiebreaker: z.ZodBoolean;
}>, {
    connectionType: z.ZodLiteral<"webrtc">;
    connectionOptions: z.ZodObject<{
        iceServers: z.ZodOptional<z.ZodArray<z.ZodObject<{
            urls: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>;
            username: z.ZodOptional<z.ZodString>;
            credential: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }, {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        iceServers?: {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }[] | undefined;
    }, {
        iceServers?: {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }[] | undefined;
    }>;
}>, "strip", z.ZodTypeAny, {
    messageType: "command";
    command: "createPeerconnection";
    connectionType: "webrtc";
    connectionUrl: string;
    services: {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }[];
    tiebreaker: boolean;
    connectionOptions: {
        iceServers?: {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }[] | undefined;
    };
}, {
    messageType: "command";
    command: "createPeerconnection";
    connectionType: "webrtc";
    connectionUrl: string;
    services: {
        serviceType: string;
        serviceId: string;
        remoteServiceId: string;
    }[];
    tiebreaker: boolean;
    connectionOptions: {
        iceServers?: {
            urls: string | string[];
            username?: string | undefined;
            credential?: string | undefined;
        }[] | undefined;
    };
}>]>;
export type CreatePeerConnectionMessage = z.infer<typeof createPeerConnectionMessageSchema>;
export declare function isCreatePeerConnectionMessage(input: unknown): input is CreatePeerConnectionMessage;
declare const signalingMessageSchema: z.ZodObject<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"signaling">;
    connectionUrl: z.ZodString;
    signalingType: z.ZodUnion<[z.ZodLiteral<"options">, z.ZodLiteral<"offer">, z.ZodLiteral<"answer">, z.ZodLiteral<"candidate">]>;
    content: z.ZodUnknown;
}>, "strip", z.ZodTypeAny, {
    messageType: "signaling";
    connectionUrl: string;
    signalingType: "options" | "offer" | "answer" | "candidate";
    content?: unknown;
}, {
    messageType: "signaling";
    connectionUrl: string;
    signalingType: "options" | "offer" | "answer" | "candidate";
    content?: unknown;
}>;
export type SignalingMessage = z.infer<typeof signalingMessageSchema>;
export declare function isSignalingMessage(input: unknown): input is SignalingMessage;
declare const closePeerConnectionMessageSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"command">;
    command: z.ZodString;
}>, {
    command: z.ZodLiteral<"closePeerconnection">;
    connectionUrl: z.ZodString;
}>, "strip", z.ZodTypeAny, {
    messageType: "command";
    command: "closePeerconnection";
    connectionUrl: string;
}, {
    messageType: "command";
    command: "closePeerconnection";
    connectionUrl: string;
}>;
export type ClosePeerConnectionMessage = z.infer<typeof closePeerConnectionMessageSchema>;
export declare function isClosePeerConnectionMessage(input: unknown): input is ClosePeerConnectionMessage;
declare const connectionStateChangedMessageSchema: z.ZodObject<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"connection-state-changed">;
    connectionUrl: z.ZodString;
    status: z.ZodUnion<[z.ZodLiteral<"new">, z.ZodLiteral<"connecting">, z.ZodLiteral<"connected">, z.ZodLiteral<"disconnected">, z.ZodLiteral<"failed">, z.ZodLiteral<"closed">]>;
}>, "strip", z.ZodTypeAny, {
    messageType: "connection-state-changed";
    status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
    connectionUrl: string;
}, {
    messageType: "connection-state-changed";
    status: "new" | "connecting" | "connected" | "disconnected" | "failed" | "closed";
    connectionUrl: string;
}>;
export type ConnectionStateChangedMessage = z.infer<typeof connectionStateChangedMessageSchema>;
declare const configurationMessageSchema: z.ZodObject<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"configuration">;
    configuration: z.ZodRecord<z.ZodString, z.ZodUnknown>;
}>, "strip", z.ZodTypeAny, {
    messageType: "configuration";
    configuration: Record<string, unknown>;
}, {
    messageType: "configuration";
    configuration: Record<string, unknown>;
}>;
export type ConfigurationMessage = z.infer<typeof configurationMessageSchema>;
export declare function isConfigurationMessage(input: unknown): input is ConfigurationMessage;
declare const experimentStatusChangedMessageSchema: z.ZodObject<z.objectUtil.extendShape<{
    messageType: z.ZodString;
}, {
    messageType: z.ZodLiteral<"experiment-status-changed">;
    status: z.ZodUnion<[z.ZodLiteral<"created">, z.ZodLiteral<"booked">, z.ZodLiteral<"setup">, z.ZodLiteral<"running">, z.ZodLiteral<"finished">]>;
    message: z.ZodOptional<z.ZodString>;
}>, "strip", z.ZodTypeAny, {
    messageType: "experiment-status-changed";
    status: "created" | "booked" | "setup" | "running" | "finished";
    message?: string | undefined;
}, {
    messageType: "experiment-status-changed";
    status: "created" | "booked" | "setup" | "running" | "finished";
    message?: string | undefined;
}>;
export type ExperimentStatusChangedMessage = z.infer<typeof experimentStatusChangedMessageSchema>;
export declare function isExperimentStatusChangedMessage(input: unknown): input is ExperimentStatusChangedMessage;
declare const serviceDescriptionSchema: z.ZodObject<{
    serviceType: z.ZodString;
    serviceId: z.ZodString;
    serviceDirection: z.ZodString;
    interfaces: z.ZodArray<z.ZodUnknown, "many">;
}, "strip", z.ZodTypeAny, {
    serviceType: string;
    serviceId: string;
    serviceDirection: string;
    interfaces: unknown[];
}, {
    serviceType: string;
    serviceId: string;
    serviceDirection: string;
    interfaces: unknown[];
}>;
export type ServiceDescription = z.infer<typeof serviceDescriptionSchema>;
declare const deviceDescriptionSchema: z.ZodObject<{
    services: z.ZodArray<z.ZodObject<{
        serviceType: z.ZodString;
        serviceId: z.ZodString;
        serviceDirection: z.ZodString;
        interfaces: z.ZodArray<z.ZodUnknown, "many">;
    }, "strip", z.ZodTypeAny, {
        serviceType: string;
        serviceId: string;
        serviceDirection: string;
        interfaces: unknown[];
    }, {
        serviceType: string;
        serviceId: string;
        serviceDirection: string;
        interfaces: unknown[];
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    services: {
        serviceType: string;
        serviceId: string;
        serviceDirection: string;
        interfaces: unknown[];
    }[];
}, {
    services: {
        serviceType: string;
        serviceId: string;
        serviceDirection: string;
        interfaces: unknown[];
    }[];
}>;
export type DeviceDescription = z.infer<typeof deviceDescriptionSchema>;
declare const webSocketMessageSchema: z.ZodUnion<[z.ZodObject<{
    type: z.ZodLiteral<"string">;
    channel: z.ZodString;
    content: z.ZodString;
}, "strip", z.ZodTypeAny, {
    type: "string";
    content: string;
    channel: string;
}, {
    type: "string";
    content: string;
    channel: string;
}>, z.ZodObject<{
    type: z.ZodUnion<[z.ZodLiteral<"arrayBuffer">, z.ZodLiteral<"blob">]>;
    channel: z.ZodString;
    content: z.ZodArray<z.ZodNumber, "many">;
}, "strip", z.ZodTypeAny, {
    type: "arrayBuffer" | "blob";
    content: number[];
    channel: string;
}, {
    type: "arrayBuffer" | "blob";
    content: number[];
    channel: string;
}>, z.ZodObject<{
    type: z.ZodLiteral<"arrayBufferView">;
    channel: z.ZodString;
    content: z.ZodObject<{
        buffer: z.ZodArray<z.ZodNumber, "many">;
        byteLength: z.ZodNumber;
        byteOffset: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        buffer: number[];
        byteLength: number;
        byteOffset: number;
    }, {
        buffer: number[];
        byteLength: number;
        byteOffset: number;
    }>;
}, "strip", z.ZodTypeAny, {
    type: "arrayBufferView";
    content: {
        buffer: number[];
        byteLength: number;
        byteOffset: number;
    };
    channel: string;
}, {
    type: "arrayBufferView";
    content: {
        buffer: number[];
        byteLength: number;
        byteOffset: number;
    };
    channel: string;
}>]>;
export type WebSocketMessage = z.infer<typeof webSocketMessageSchema>;
export declare function isWebSocketMessage(input: unknown): input is WebSocketMessage;
export {};
//# sourceMappingURL=deviceMessages.d.ts.map